/*
 * The MIT License
 *
 * Copyright 2021 Sebastian Schauer.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package sudoku.controller;

import java.util.ArrayList;
import java.util.List;
import sudoku.model.board.Cell;

/**
 * A POJO class for transmitting sudokus between view and model.
 * Here: Sudoku areas are transported.
 * 
 * @author Sebastian Schauer
 */
public class AreaTransport {
    
    /**
     * A list of x-y pairs of the contained cells
     */
    public List<int[]> cellCoord;
    /**
     * Whether this area is to be drawn in a special way
     */
    public boolean foreground;
    
    /**
     * The constructor
     */
    public AreaTransport() {
        cellCoord = new ArrayList<>();
    }
    
    /**
     * Adds a cell to the area.
     * @param x The x coordinate (0-based) of the cell
     * @param y The y coordinate (0-based) of the cell
     */
    public void addCell(int x, int y) {        
        cellCoord.add(new int[] {x, y});
    }
    
    /**
     * Adds a cell to the area.
     * @param cell The cell to be added
     */
    public void addCell(Cell cell) {
        addCell(cell.getX(), cell.getY());
    }
}
