/*
 * The MIT License
 *
 * Copyright 2021 Sebastian Schauer.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package sudoku.controller;

import java.util.ArrayList;
import java.util.List;
import sudoku.model.games.GameType;

/**
 * A POJO object for transportating sudokus between model and view.
 * @author Sebastian Schauer
 */
public class SudokuTransport {
    /**
     * The type of the sudoku
     */
    public GameType type;
    /**
     * The size of the sudoku
     */
    public int size;
    /**
     * The cell values of the sudoku (0 = empty)
     */
    public int[][] values;
    /**
     * The areas of the sudoku
     */
    public List<AreaTransport> areas;
    /**
     * The number of foreground colors of the sudoku
     */
    public int foregroundColors;
    
    /**
     * The constructor
     */
    public SudokuTransport() {
        areas = new ArrayList<>();
    }
    
    /**
     * The constructor
     * @param size The size of the sudoku
     */
    public SudokuTransport(int size) {
        this.type = GameType.Regular;
        this.size = size;
        this.values = new int[size][size];
        this.areas = new ArrayList<>();
        this.foregroundColors = 0;
    }
}
