/*
 * The MIT License
 *
 * Copyright 2021 Sebastian Schauer.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package sudoku.model.games;

import sudoku.controller.GameController;
import sudoku.model.board.Area;
import sudoku.model.board.Sudoku;

/**
 * A hyper sudoku. Works like a regular sudoku, but has some additional
 * areas.
 * 
 * @author Sebastian Schauer
 */
public class HyperSudoku extends RegularSudoku {

    public HyperSudoku(int size, GameController gc) {
        super(size, gc);
        name = "Hypersudoku";
        type = GameType.Hyper;
        for (int x = 1; x < size; x += root + 1) {
            for (int y = 1; y < size; y += root + 1) {
                Area a = new Area(size, true);
                for (int i = 0; i < root; i++) {
                    for (int j = 0; j < root; j++) {
                        a.addCell(cells[x + i][y + j]);
                    }
                }
                areas.add(a);
            }
        }
        super.foregroundColors = 1;
    }
    
    /**
     * Copies this sudoku.
     * @return The copy
     */
    @Override
    public Sudoku copy() {
        return super.copy(new HyperSudoku(size, myGC));
    }
}
